#ifndef BODY_CTRL_H
#define BODY_CTRL_H

/*!
  \file
  \brief ixA]w肵➑̂̐

  \author Satofumi KAMIMURA

  $Id$
*/

#include "wheelCtrl.h"


/*!
  \brief ➑̏̊Ǘ
*/
typedef struct {
  wheelInfo_t *whl[2];
  int mtr_direction[2];	      /*!< ԗւƃ[^̎t̏ */
  int tread_mm;
  int div2vel_const;
} bodyInfo_t;


enum MtrDirSettings {
  WHL_CW_FWD = +1,	/*!< [^ CW ]ŁAOiɈړ */
  WHL_CW_BACK = -1,	/*!< [^ CW ]ŁAiɈړ */

  BODY_WHL_RIGHT = 0,
  BODY_WHL_LEFT = 1,

  DIV2VEL_CONST_SHIFT = 4,
};


#ifndef BODY_TREAD_MM
#define BODY_TREAD_MM 290.7
#endif

#ifndef DEFAULT_WHL_RIGHT
#define DEFAULT_WHL_RIGHT WHL_CW_BACK /*! Eւ CW䎞̈ړ */
#endif
#ifndef DEFAULT_WHL_LEFT
#define DEFAULT_WHL_LEFT WHL_CW_BACK /*! Eւ CW䎞̈ړ */
#endif


//#include "cpp_extern_macro.h"
BEGIN_C_DECLS;

extern void initBodyInfo(bodyInfo_t *body,
			 wheelInfo_t *right, wheelInfo_t *left);
extern int change_bodyDiv2Whl(int div16_vel, bodyInfo_t *body);
extern void setBodyMove(bodyInfo_t *body,
			int straight_mm_vel, int rotate_div16_vel);

END_C_DECLS;
#endif /* !BODY_CTRL_H */
